California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 36 - DRUG TREATMENT DIVERSION PROGRAM. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
992045 | CALIFORNIA CAMPAIGN FOR NEW DRUG POLICIES, YES ON PROP. 36 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1225971 | CALIFORNIANS FOR CRIME PREVENTION AND FOR PROPOSITION 36 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1223780 | CALIFORNIANS UNITED AGAINST DRUG ABUSE SPONSORED BY: LAW ENFORCEMNET, DRUG TREATMENT PROFESSIONALS, HEALTHCARE, CRIME VICTIMS AND TAXPAYERS - NO ON 36 | OPPOSE